==> igniteui-react-inputs-18.1.3.tgz: package/esm2015/lib/XInputBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { typeCast, runOn, delegateCombine, delegateRemove, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { XInput } from "./XInput";
import { NativeUIInputChangingEventArgs } from "igniteui-react-core";
import { NativeUIDisplayDensity_$type } from "igniteui-react-core";
import { NativeUIInputDisplayType_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { NativeUIInputType_$type } from "igniteui-react-core";
/**
 * @hidden
 */
export let XInputBridge = /*@__PURE__*/ (() => {
    class XInputBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.e = null;
            this.d = null;
            this.g = null;
            this.f = null;
        }
        addHandler(a, b, c, d) {
            let e = a;
            let f = typeCast(XInput.$, e.inputs._inner[0]);
            switch (c) {
                case 0:
                    f.changing = delegateCombine(f.changing, runOn(this, this.i));
                    this.e = d;
                    this.g = b;
                    break;
                case 2:
                    f.change = delegateCombine(f.change, runOn(this, this.h));
                    this.d = d;
                    this.f = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            let f = typeCast(XInput.$, e.inputs._inner[0]);
            switch (c) {
                case 0:
                    f.changing = delegateRemove(f.changing, runOn(this, this.i));
                    this.e = null;
                    this.g = null;
                    break;
                case 2:
                    f.change = delegateRemove(f.change, runOn(this, this.h));
                    this.d = null;
                    this.f = null;
                    break;
            }
        }
        i(a, b) {
            if (this.e != null) {
                let c = new NativeUIInputChangingEventArgs();
                this.e(this.g, c);
            }
        }
        h(a, b) {
            if (this.d != null) {
                let c = new NativeUIInputChangingEventArgs();
                this.d(this.f, c);
            }
        }
        getValue(a, b) {
            let c = a;
            let d = typeCast(XInput.$, c.inputs._inner[0]);
            switch (b) {
                case 2: return d.cm;
                case 1:
                    switch (c.n) {
                        case 0: return enumGetBox(NativeUIDisplayDensity_$type, 0);
                        case 1: return enumGetBox(NativeUIDisplayDensity_$type, 1);
                        case 3: return enumGetBox(NativeUIDisplayDensity_$type, 2);
                        case 2: return enumGetBox(NativeUIDisplayDensity_$type, 3);
                    }
                    break;
                case 0:
                    switch (c.d) {
                        case 2: return enumGetBox(NativeUIInputDisplayType_$type, 1);
                        case 1: return enumGetBox(NativeUIInputDisplayType_$type, 2);
                        case 0: return enumGetBox(NativeUIInputDisplayType_$type, 0);
                    }
                    break;
                case 16: return enumGetBox(BaseControlTheme_$type, c.j);
                case 17:
                    switch (d.b6) {
                        case "text": return enumGetBox(NativeUIInputType_$type, 0);
                        case "number": return enumGetBox(NativeUIInputType_$type, 1);
                    }
                    break;
            }
            return null;
        }
        setValue(a, b, c) {
            let d = a;
            let e = typeCast(XInput.$, d.inputs._inner[0]);
            switch (b) {
                case 2:
                    e.cm = c == null ? null : c.toString();
                    break;
                case 1:
                    switch (EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, c)) {
                        case 0:
                            d.n = 0;
                            break;
                        case 1:
                            d.n = 1;
                            break;
                        case 2:
                            d.n = 3;
                            break;
                        case 3:
                            d.n = 2;
                            break;
                    }
                    break;
                case 0:
                    switch (EnumUtil.getEnumValue(NativeUIInputDisplayType_$type, c)) {
                        case 1:
                            d.d = 2;
                            break;
                        case 2:
                            d.d = 1;
                            break;
                        case 0:
                            d.d = 0;
                            break;
                    }
                    break;
                case 16:
                    d.j = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                    break;
                case 17:
                    switch (EnumUtil.getEnumValue(NativeUIInputType_$type, c)) {
                        case 0:
                            e.b6 = "text";
                            break;
                        case 1:
                            e.b6 = "number";
                            break;
                    }
                    break;
            }
        }
        getTargetForProperty(a, b) {
            switch (a) {
                case 9:
                case 10: return b;
            }
            return super.getTargetForProperty(a, b);
        }
    }
    XInputBridge.$t = /*@__PURE__*/ markType(XInputBridge, 'XInputBridge', XComponentBridge.$);
    return XInputBridge;
})();

==> igniteui-react-inputs-18.6.1.tgz: package/esm2015/lib/XInputBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { INativeUIInputBridge_$type } from "igniteui-react-core";
import { typeCast, runOn, delegateCombine, delegateRemove, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { XInput } from "./XInput";
import { NativeUIInputChangingEventArgs } from "igniteui-react-core";
import { NativeUIDisplayDensity_$type } from "igniteui-react-core";
import { NativeUIInputDisplayType_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { NativeUIInputType_$type } from "igniteui-react-core";
import { NativeUIComponentHorizontalAlignment_$type } from "igniteui-react-core";
/**
 * @hidden
 */
export let XInputBridge = /*@__PURE__*/ (() => {
    class XInputBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.v = null;
            this.u = null;
            this.x = null;
            this.w = null;
        }
        addHandler(a, b, c, d) {
            let e = a;
            let f = typeCast(XInput.$, e.inputs._inner[0]);
            switch (c) {
                case 0:
                    f.changing = delegateCombine(f.changing, runOn(this, this.z));
                    this.v = d;
                    this.x = b;
                    break;
                case 2:
                    f.change = delegateCombine(f.change, runOn(this, this.y));
                    this.u = d;
                    this.w = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            let f = typeCast(XInput.$, e.inputs._inner[0]);
            switch (c) {
                case 0:
                    f.changing = delegateRemove(f.changing, runOn(this, this.z));
                    this.v = null;
                    this.x = null;
                    break;
                case 2:
                    f.change = delegateRemove(f.change, runOn(this, this.y));
                    this.u = null;
                    this.w = null;
                    break;
            }
        }
        z(a, b) {
            if (this.v != null) {
                let c = new NativeUIInputChangingEventArgs();
                this.v(this.x, c);
            }
        }
        y(a, b) {
            if (this.u != null) {
                let c = new NativeUIInputChangingEventArgs();
                this.u(this.w, c);
            }
        }
        getValue(a, b) {
            let c = a;
            let d = typeCast(XInput.$, c.inputs._inner[0]);
            switch (b) {
                case 2: return d.cq;
                case 1:
                    switch (c.t) {
                        case 0: return enumGetBox(NativeUIDisplayDensity_$type, 0);
                        case 1: return enumGetBox(NativeUIDisplayDensity_$type, 1);
                        case 3: return enumGetBox(NativeUIDisplayDensity_$type, 2);
                        case 2: return enumGetBox(NativeUIDisplayDensity_$type, 3);
                    }
                    break;
                case 0:
                    switch (c.d) {
                        case 2: return enumGetBox(NativeUIInputDisplayType_$type, 1);
                        case 1: return enumGetBox(NativeUIInputDisplayType_$type, 2);
                        case 0: return enumGetBox(NativeUIInputDisplayType_$type, 0);
                    }
                    break;
                case 18: return enumGetBox(BaseControlTheme_$type, c.p);
                case 19:
                    switch (d.b8) {
                        case "text": return enumGetBox(NativeUIInputType_$type, 0);
                        case "number": return enumGetBox(NativeUIInputType_$type, 1);
                    }
                    break;
                case 20:
                    switch (d.dy) {
                        case 0: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 0);
                        case 2: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 2);
                        case 1: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 1);
                        case 3: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 3);
                    }
                    break;
                case 21: return d.a1;
                case 32: return d.disabled;
                case 33: return d.d8;
            }
            return null;
        }
        setValue(a, b, c) {
            let d = a;
            let e = typeCast(XInput.$, d.inputs._inner[0]);
            switch (b) {
                case 2:
                    e.cq = c == null ? null : c.toString();
                    break;
                case 1:
                    switch (EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, c)) {
                        case 0:
                            d.t = 0;
                            break;
                        case 1:
                            d.t = 1;
                            break;
                        case 2:
                            d.t = 3;
                            break;
                        case 3:
                            d.t = 2;
                            break;
                    }
                    break;
                case 0:
                    switch (EnumUtil.getEnumValue(NativeUIInputDisplayType_$type, c)) {
                        case 1:
                            d.d = 2;
                            break;
                        case 2:
                            d.d = 1;
                            break;
                        case 0:
                            d.d = 0;
                            break;
                    }
                    break;
                case 18:
                    d.p = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                    break;
                case 19:
                    switch (EnumUtil.getEnumValue(NativeUIInputType_$type, c)) {
                        case 0:
                            e.b8 = "text";
                            break;
                        case 1:
                            e.b8 = "number";
                            break;
                    }
                    break;
                case 20:
                    switch (EnumUtil.getEnumValue(NativeUIComponentHorizontalAlignment_$type, c)) {
                        case 0:
                            e.dy = 0;
                            break;
                        case 2:
                            e.dy = 2;
                            break;
                        case 1:
                            e.dy = 1;
                            break;
                        case 3:
                            e.dy = 3;
                            break;
                    }
                    break;
                case 21:
                    e.a1 = c;
                    break;
                case 32:
                    e.disabled = c;
                    break;
                case 33:
                    e.d8 = c;
                    break;
            }
        }
        getTargetForProperty(a, b) {
            switch (a) {
                case 9:
                case 10: return b;
            }
            return super.getTargetForProperty(a, b);
        }
        focus(a) {
            let b = this.t;
            let c = b.inputs._inner[0];
            c.focus(true);
        }
        select(a) {
            let b = a;
            let c = b.inputs._inner[0];
            window.setTimeout(() => c.dp(), 0);
        }
        setSelectionRange(a, b, c) {
            let d = a;
            let e = d.inputs._inner[0];
            window.setTimeout(() => e.dr(b, c), 0);
        }
    }
    XInputBridge.$t = /*@__PURE__*/ markType(XInputBridge, 'XInputBridge', XComponentBridge.$, [INativeUIInputBridge_$type]);
    return XInputBridge;
})();
